{
    description = "An alternative to FZF written in Go, specifically optimized for file path selection.";
    inputs = {
        nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
        flake-parts = {
            url = "github:hercules-ci/flake-parts";
            inputs.nixpkgs-lib.follows = "nixpkgs";
        };
    };

    outputs = inputs @ {flake-parts, ...}:
        flake-parts.lib.mkFlake {inherit inputs;} {
            systems = ["x86_64-linux" "aarch64-linux"];
            perSystem = {
                pkgs,
                lib,
                ...
                }: let
                    fzgo = pkgs.buildGoModule {
                        pname = "fzgo";
                        version = "0.1.0";

                        src = builtins.path {
                            name = "fzgo-source";
                            path = ./src;
                        };
                        vendorHash = "sha256-0YG2kf1500UpSdDK+ONGTKGZFrIivi/O1g2uIkgd4DA=";
                        meta = with lib; {
                            description = "An alternative to FZF written in Go, specifically optimized for file path selection.";
                            homepage = "https://git.thomasave.be/thomasave/fzgo";
                            license = licenses.mit;
                            maintainers = with maintainers; [thomasave];
                            platforms = platforms.linux;
                            mainProgram = "fzgo";
                        };
                    };
                in {
                    formatter = pkgs.alejandra;
                    packages = {
                        default = fzgo;
                        inherit fzgo;
                    };
                };
        };
}
