package main

import (
	"flag"
	"fmt"
	"log"
	"os"

	"github.com/charmbracelet/bubbles/list"
	tea "github.com/charmbracelet/bubbletea"
	"github.com/charmbracelet/lipgloss"
	"github.com/muesli/termenv"
)

func main() {
	lipgloss.DefaultRenderer().SetColorProfile(termenv.TrueColor)

	// Command-line flags
	searchFiles := flag.Bool("f", false, "Search for files")
	searchDirs := flag.Bool("d", false, "Search for directories")
	flag.Parse()

    if !*searchFiles && !*searchDirs {
        *searchFiles = true
        *searchDirs = true
    }

	// Gather list items for each path
	var items []list.Item

	// Read paths from command line arguments
	if len(flag.Args()) < 1 {
		items = getListItemsFromStdin()
	} else {
		paths := flag.Args()
		for _, path := range paths {
            items = append(items, getListItemsFromDir(path, *searchDirs, *searchFiles)...)
		}
	}

	p := tea.NewProgram(initialModel(items), tea.WithOutput(os.Stderr))
	m, err := p.Run()
	if err != nil {
		log.Fatal(err)
	} else {
		fmt.Println(m.View())
	}
}
